#[non_exhaustive]pub enum ConnectorError {
Show 21 variants
ConnectionError(String),
NotConnected,
NotRegistered,
StreamError(String),
RegistrationError(String),
InvalidConfig(String),
SerializationError(String),
DeserializationError(String),
UnsupportedEncoding(String),
Timeout(String),
InvokeFailed(String),
NotRunning,
AlreadyRunning,
Io(Box<Error>),
Grpc(Box<Status>),
Json(Box<Error>),
NotImplemented(String),
ProxyUnreachable(String),
ProxyConnectFailed(String),
ProxyAuthFailed(String),
Other(String),
}Expand description
Connector error types.
Marked #[non_exhaustive] so adding new variants in subsequent releases
does not break downstream match statements that handle the variants
they care about. Downstream code must include a wildcard arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConnectionError(String)
NotConnected
NotRegistered
StreamError(String)
RegistrationError(String)
InvalidConfig(String)
SerializationError(String)
DeserializationError(String)
UnsupportedEncoding(String)
Timeout(String)
InvokeFailed(String)
NotRunning
AlreadyRunning
Io(Box<Error>)
Grpc(Box<Status>)
Json(Box<Error>)
NotImplemented(String)
ProxyUnreachable(String)
ProxyConnectFailed(String)
ProxyAuthFailed(String)
Other(String)
Implementations
Sourceimpl ConnectorError
impl ConnectorError
pub fn code(&self) -> &'static str
Sourcepub fn is_recoverable(&self) -> bool
pub fn is_recoverable(&self) -> bool
Whether this error is transient and reconnection may succeed.
Non-recoverable errors (invalid config, permanent registration rejection, serialization bugs) should stop the reconnect loop to avoid wasting resources and hiding real problems.