pub enum ConnectorError {
Show 18 variants
ConnectionError(String),
NotConnected,
NotRegistered,
StreamError(String),
RegistrationError(String),
InvalidConfig(String),
SerializationError(String),
DeserializationError(String),
UnsupportedEncoding(String),
Timeout(String),
InvokeFailed(String),
NotRunning,
AlreadyRunning,
Io(Box<Error>),
Grpc(Box<Status>),
Json(Box<Error>),
NotImplemented(String),
Other(String),
}Expand description
Connector error types
Variants
ConnectionError(String)
NotConnected
NotRegistered
StreamError(String)
RegistrationError(String)
InvalidConfig(String)
SerializationError(String)
DeserializationError(String)
UnsupportedEncoding(String)
Timeout(String)
InvokeFailed(String)
NotRunning
AlreadyRunning
Io(Box<Error>)
Grpc(Box<Status>)
Json(Box<Error>)
NotImplemented(String)
Other(String)
Implementations
Sourceimpl ConnectorError
impl ConnectorError
pub fn code(&self) -> &'static str
Sourcepub fn is_recoverable(&self) -> bool
pub fn is_recoverable(&self) -> bool
Whether this error is transient and reconnection may succeed.
Non-recoverable errors (invalid config, permanent registration rejection, serialization bugs) should stop the reconnect loop to avoid wasting resources and hiding real problems.